/*
 * Copyright 2003 - 2010 The eFaps Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Revision:        $Rev: 5420 $
 * Last Changed:    $Date: 2010-08-26 13:27:27 -0500 (Thu, 26 Aug 2010) $
 * Last Changed By: $Author: jan.moxter $
 */

package org.efaps.admin.datamodel.attributetype;

import java.sql.SQLException;
import java.util.List;

import org.efaps.admin.datamodel.Attribute;
import org.efaps.admin.datamodel.Type;
import org.efaps.db.query.CachedResult;
import org.efaps.db.wrapper.SQLUpdate;

/**
 * Implements the mapping between values in the database and {@link Type}
 * values in eFaps.
 *
 * @author The eFaps Team
 * @version $Id: TypeType.java 5420 2010-08-26 18:27:27Z jan.moxter $
 */
public class TypeType
    extends AbstractType
{
    /**
     * {@inheritDoc}
     */
    @Override
    public void prepareUpdate(final SQLUpdate _update,
                              final Attribute _attribute,
                              final Object... _values)
        throws SQLException
    {
        throw new SQLException("Update value for Type not allowed!!!");
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Object readValue(final Attribute _attribute,
                            final CachedResult _rs,
                            final List<Integer> _indexes)
        throws Exception
    {
        Type ret;
        if (!_attribute.getSqlColNames().isEmpty()) {
            ret = Type.get(_rs.getLong(_indexes.get(0).intValue()));
        } else {
            ret = _attribute.getParent();
        }
        return ret;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Object readValue(final Attribute _attribute,
                            final List<Object> _objectList)
    {
        Type ret;
        if (!_attribute.getSqlColNames().isEmpty()) {
            ret = Type.get((Long) _objectList.get(0));
        } else {
            ret = _attribute.getParent();
        }
        return ret;
    }
}
