/*
0 * Copyright 2003 - 2010 The eFaps Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Revision:        $Rev: 5421 $
 * Last Changed:    $Date: 2010-08-26 13:41:01 -0500 (Thu, 26 Aug 2010) $
 * Last Changed By: $Author: jan.moxter $
 */

package org.efaps.admin.datamodel.ui;

import java.text.DecimalFormat;
import java.text.NumberFormat;

import org.efaps.admin.datamodel.Attribute;
import org.efaps.admin.datamodel.Dimension;
import org.efaps.admin.datamodel.Dimension.UoM;
import org.efaps.admin.datamodel.attributetype.DecimalType;
import org.efaps.admin.dbproperty.DBProperties;
import org.efaps.admin.ui.AbstractUserInterfaceObject.TargetMode;
import org.efaps.admin.ui.field.Field;
import org.efaps.db.Context;
import org.efaps.util.EFapsException;


/**
 * Class to represent a String for the user interface.
 *
 * @author The eFaps Team
 * @version $Id: DecimalWithUoMUI.java 5421 2010-08-26 18:41:01Z jan.moxter $
 *
 */
public class DecimalWithUoMUI
    extends AbstractUI
{

    /**
     * Needed for serialization.
     */
    private static final long serialVersionUID = 1L;

    /**
     * {@inheritDoc}
     *
     */
    @Override
    public String getReadOnlyHtml(final FieldValue _fieldValue)
        throws EFapsException
    {
        final StringBuilder ret = new StringBuilder();
        final Field field = _fieldValue.getField();
        final Object value = _fieldValue.getValue();

        if (value instanceof Object[]) {
            final Object[] values =  (Object[]) value;
            final DecimalFormat formatter = (DecimalFormat) NumberFormat.getInstance(Context.getThreadContext()
                            .getLocale());
            final String strValue = values[0] instanceof Number ? formatter.format(values[0]) : values[0].toString();
            final UoM uom = (UoM) values[1];
            ret.append("<span><span name=\"").append(field.getName()).append("\" ")
                .append(UIInterface.EFAPSTMPTAG).append(">")
                .append(strValue).append("</span>&nbsp;")
                .append("<span name=\"").append(field.getName()).append("UoM\" ").append(">")
                .append(uom.getName()).append("</span></span>");
        }
        return ret.toString();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getEditHtml(final FieldValue _fieldValue)
        throws EFapsException
    {
        final StringBuilder ret = new StringBuilder();
        final Field field = _fieldValue.getField();
        final Object value = _fieldValue.getValue();
        String strValue = null;
        UoM uomValue = null;
        if (value instanceof Object[]) {
            final Object[] values =  (Object[]) value;
            final DecimalFormat formatter
                = (DecimalFormat) NumberFormat.getInstance(Context.getThreadContext().getLocale());
            strValue = values[0] instanceof Number ? formatter.format(values[0]) : values[0].toString();
            uomValue = (UoM) values[1];
        }

        if (_fieldValue.getTargetMode().equals(TargetMode.SEARCH)) {
            ret.append("<input type=\"text\" size=\"").append(field.getCols())
                .append("\" name=\"").append(field.getName())
                .append("\" value=\"").append(value != null ? value : "*").append("\" />");
        } else {
            ret.append("<span><input type=\"text\" size=\"").append(field.getCols())
                .append("\" name=\"").append(field.getName())
                .append("\" value=\"").append(strValue != null ? strValue : "").append("\"")
                .append(UIInterface.EFAPSTMPTAG).append("/>")
                .append("<select name=\"").append(_fieldValue.getField().getName()).append("UoM\" size=\"1\">");

            final Dimension dim = _fieldValue.getAttribute().getDimension();
            for (final UoM uom : dim.getUoMs()) {
                ret.append("<option value=\"").append(uom.getId());
                if ((uomValue == null && uom.equals(dim.getBaseUoM())) || (uomValue != null && uomValue.equals(uom))) {
                    ret.append("\" selected=\"selected");
                }
                ret.append("\">").append(uom.getName()).append("</option>");
            }
            ret.append("</select></span>");

        }
        return ret.toString();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String validateValue(final String _value,
                                final Attribute _attribute)
    {
        String ret = null;
        try {
            DecimalType.parseLocalized(_value);
        } catch (final EFapsException e) {
            ret = DBProperties.getProperty(DecimalUI.class.getName() + ".InvalidValue");
        }
        return ret;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Object format(final Object _object,
                         final String _pattern)
        throws EFapsException
    {
        final Object ret;
        final DecimalFormat formatter
            = (DecimalFormat) NumberFormat.getInstance(Context.getThreadContext().getLocale());
        formatter.applyPattern(_pattern);
        if (_object instanceof Object[]) {
            final String tmp = formatter.format(((Object[]) _object)[0]);
            ((Object[]) _object)[0] = tmp;
            ret = _object;
        } else {
            ret = formatter.format(_object);
        }
        return ret;
    }
}
