/*
 * Copyright 2003 - 2010 The eFaps Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Revision:        $Rev: 5089 $
 * Last Changed:    $Date: 2010-07-27 12:57:14 -0500 (Tue, 27 Jul 2010) $
 * Last Changed By: $Author: jan.moxter $
 */

package org.efaps.db.print;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.efaps.admin.datamodel.Type;
import org.efaps.db.wrapper.SQLSelect;

/**
 * Interface used for the different Select parts.
 *
 * @author The eFaps Team
 * @version $Id: ISelectPart.java 5089 2010-07-27 17:57:14Z jan.moxter $
 */
public interface ISelectPart
{
    /**
     * Method to join a table to the given from select statement.
     *
     * @param _oneselect    oneselect this select part must be joined to
     * @param _select       SQL select statement wrapper
     * @param _relIndex     relation index
     * @return table index of the joint table
     */
    int join(final OneSelect _oneselect,
             final SQLSelect _select,
             final int _relIndex);

    /**
     * Method to get the Type the part belongs to.
     * @return type
     */
    Type getType();

    /**
     * Add an Object.
     * @param _rs ResultSet
     * @throws SQLException on error
     */
    void addObject(final ResultSet _rs)
        throws SQLException;

    /**
     * Get the Object that was added using {@link #addObject(ResultSet)}.
     * @return Object
     */
    Object getObject();
}
